<template>
  <div class="app-container">
    <el-card class="box-card" >
      <el-row>
        <el-divider><span style="font-size: 30px">发动机返修标记系统</span></el-divider>
      </el-row>
      <el-row style="margin-top: 10px">
        <el-form :model="queryParams.sfcCode" ref="queryForm" :inline="true" label-width="68px" >
          <el-form-item label-width="120" label="发动机号:" prop="orderNo">
            <el-input
              v-model="queryParams.sfcCode"
              placeholder="请输入发动机号"
              clearable
              @keyup.enter.native="handleQuery"
            />
          </el-form-item>
          <el-form-item style="margin-left: 20px">
            <el-button type="primary" icon="el-icon-refresh" @click="handleQuery">查询</el-button>
            <el-button type="primary" icon="el-icon-scissors" @click="repairProgressHandleQuery">返修进度</el-button>
          </el-form-item>
        </el-form>
      </el-row>
    </el-card>
    <el-row>
      <el-col :span="20">
        <el-card style="margin-top: 10px; height: 490px;" class="box-card">
          <el-tabs v-model="activeName" @tab-click="handleClick">
            <el-tab-pane label="过站采集" name="first">
              <el-table max-height="410px" border ref="multipleTable" :data="passingStationCollectionList"  @selection-change="handleSelectionChange">
                <el-table-column type="selection" width="55" align="center" />
                <el-table-column label="工单编号" width="120" align="center" prop="workOrderNo">
                </el-table-column>
                <el-table-column label="总成序列号" width="150" align="center" prop="sfcCode">
                </el-table-column>
                <el-table-column label="产品编号" align="center" prop="productCode">
                </el-table-column>
                <el-table-column label="产线编号" align="center" prop="productionLine">
                </el-table-column>
                <el-table-column label="工位编号" align="center" prop="locationCode">
                </el-table-column>
                <el-table-column label="入站时间" align="center" prop="inboundTime" width="160">
                  <template slot-scope="scope">
                    <span>{{ parseTime(scope.row.inboundTime, '{y}-{m}-{d} {h}:{i}:{s}') }}</span>
                  </template>
                </el-table-column>
                <el-table-column label="出站时间" align="center" prop="outboundTime" width="160">
                  <template slot-scope="scope">
                    <span>{{ parseTime(scope.row.outboundTime, '{y}-{m}-{d} {h}:{i}:{s}') }}</span>
                  </template>
                </el-table-column>
                <el-table-column label="是否合格" align="center" prop="outRsSign">
                </el-table-column>
                <el-table-column label="NG原因" align="center" prop="outMsgSign">
                </el-table-column>
                <el-table-column label="采集时间" align="center" prop="collectionTime" width="160">
                  <template slot-scope="scope">
                    <span>{{ parseTime(scope.row.collectionTime, '{y}-{m}-{d} {h}:{i}:{s}') }}</span>
                  </template>
                </el-table-column>
                <el-table-column label="节拍时间" align="center" prop="beatTime">
                </el-table-column>
              </el-table>
            </el-tab-pane>
            <el-tab-pane label="返修记录" name="second">
              <el-table max-height="410px" border :data="repairRecordList">
                <el-table-column label="发动机号" width="150" align="center" prop="boxCode" />
                <el-table-column label="工位号" align="center" prop="processesCode" />
                <el-table-column label="返修结果" align="center" prop="repairResults" />
                <el-table-column label="原结果" align="center" prop="originalResult" />
                <el-table-column label="返修时间" align="center" width="160" prop="repairTime" />
              </el-table>
            </el-tab-pane>
          </el-tabs>

        </el-card>
      </el-col>
      <el-col :span="4">
        <el-card style="margin-top: 10px; min-height: 490px">
          <el-row class="centered-row">
            <el-button type="success" style="margin-top: 10px;width:120px;height:40px" icon="el-icon-s-grid" @click="selectAll" >选 择 所 有</el-button>
          </el-row>
          <el-row class="centered-row">
            <el-button type="success" style="margin-top: 10px;width:120px;height:40px" icon="el-icon-close" @click="clearAll">取 消 选 择</el-button>
          </el-row>
          <el-row class="centered-row">
            <el-button type="success" style="margin-top: 10px;width:120px;height:40px" icon="el-icon-document-remove" @click="selectUnqualified">选择不合格</el-button>
          </el-row>
          <el-row class="centered-row">
            <el-button type="success" style="margin-top: 10px;width:120px;height:40px" icon="el-icon-s-flag" @click="markComplete">标 记 完 成</el-button>
          </el-row>
          <el-row class="centered-row">
          <el-button type="success" style="margin-top: 10px;width:120px;height:40px" icon="el-icon-files" @click="repairRecord">返 修 记 录</el-button>
        </el-row>
          <el-row class="centered-row">
            <el-button type="success" style="margin-top: 10px;width:120px;height:40px" icon="el-icon-date" @click="operationLog" >操 作 日 志</el-button>
          </el-row>
        </el-card>
      </el-col>
    </el-row>


  </div>
</template>

<script>
import {
  noPageList,
  insertRepairRecordByIds
} from "@/api/main/da/passingStationCollection/passingStationCollection";
import {noPagelist} from "@/api/main/rm/repairRecord/repairRecord";
export default {
  name: "index",
  dicts: ['sys_normal_disable'],
  data(){
    return{
      activeName: 'first',

      // 返修记录表格数据
      repairRecordList: [],
      // 是否显示弹出层
      open: false,
      // 产品过站采集表格数据
      passingStationCollectionList: [],
      // 查询参数
      queryParams: {
        sfcCode: '',
        outRsSign: '',
      },
      ids: [],
      allSelected: false,
      boxCode: '',

    }
  },
  mounted() {
    // this.getList()
  },
  methods:{
    // 取消按钮
    cancel() {
      this.open = false;
    },
    selectAll(){
      this.passingStationCollectionList.forEach(row => {
        this.$refs.multipleTable.toggleRowSelection(row);
      });
    },
    clearAll(){
      this.$refs.multipleTable.clearSelection();
    },
    selectUnqualified(){
      let outRsSign = this.passingStationCollectionList.filter(row => row.outRsSign === '合格')
      outRsSign.forEach(row => {
        this.$refs.multipleTable.toggleRowSelection(row);
      })
      this.$modal.msgSuccess('选择不合格');
    },
    markComplete(){
      if(this.ids.length === 0){
        this.$modal.msgSuccess('未选择');
      }else {
        this.$modal.msgSuccess('标记完成');
        let queryParams = {
          ids: this.ids
        }
        insertRepairRecordByIds(queryParams).then(response => {

        });
      }
    },
    repairRecord(){
      this.$modal.msgSuccess('返修记录');
    },
    operationLog(){
      this.$modal.msgSuccess('操作日志');
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    repairProgressHandleQuery(){
      this.activeName = 'second'
    },
    initRepairRecord(){
      /** 查询返修记录列表 */
      let queryParams = {
        boxCode: this.queryParams.sfcCode
      }
      noPagelist(queryParams).then(response => {
        this.repairRecordList = response.rows;
      });
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.getList();
      this.initRepairRecord();
    },
    /** 查询产品过站采集列表 */
    getList() {
      noPageList(this.queryParams).then(response => {
        this.passingStationCollectionList = response.rows;
        this.total = response.total;
      });
    },

  },
}
</script>

<style scoped>
::v-deep .el-form-item__label{
  font-size: large;
}
.el-icon-close {
  margin-left: 20px;
}
.centered-row {
  margin-top: 10px;
  display: flex;
  justify-content: center;
}
</style>
